@@ -8,7 +8,6 @@
 
 #include <KSharedConfig>
 
-#include <QDebug>
 #include <QJsonDocument>
 #include <QMenu>
 #include <QProcess>
@@ -20,7 +19,7 @@
 RecentFilesModel::RecentFilesModel(QObject *parent)
     : QAbstractListModel(parent)
 {
-    auto config = KSharedConfig::openConfig(Global::instance()->appConfigFilePath());
+    auto config = KSharedConfig::openConfig(Global::instance()->appConfigFilePath(Global::ConfigFile::RecentFiles));
     m_recentFilesConfigGroup = config->group(QStringLiteral("RecentFiles"));
     setMaxRecentFiles(GeneralSettings::maxRecentFiles());
     populate();
@@ -64,6 +63,11 @@ QHash<int, QByteArray> RecentFilesModel::roleNames() const
 
 void RecentFilesModel::populate()
 {
+    if (GeneralSettings::maxRecentFiles() <= 0) {
+        deleteEntries();
+        return;
+    }
+
     clear();
     setMaxRecentFiles(GeneralSettings::maxRecentFiles());
 
@@ -94,6 +98,9 @@ void RecentFilesModel::addUrl(const QString &path, const QString &name)
     }
 
     auto url = QUrl::fromUserInput(path);
+    if (!url.isValid()) {
+        return;
+    }
 
     if (url.scheme().startsWith(QStringLiteral("http")) && name.isEmpty()) {
         getHttpItemInfo(url);
@@ -166,12 +173,12 @@ void RecentFilesModel::setMaxRecentFiles(int _maxRecentFiles)
 
 void RecentFilesModel::getHttpItemInfo(const QUrl &url)
 {
-    auto ytdlProcess = new QProcess();
+    auto ytdlProcess = std::make_shared<QProcess>();
     ytdlProcess->setProgram(Application::youtubeDlExecutable());
     ytdlProcess->setArguments(QStringList() << QStringLiteral("-j") << url.toString());
     ytdlProcess->start();
 
-    connect(ytdlProcess, QOverload<int, QProcess::ExitStatus>::of(&QProcess::finished), this, [=](int, QProcess::ExitStatus) {
+    connect(ytdlProcess.get(), QOverload<int, QProcess::ExitStatus>::of(&QProcess::finished), this, [=](int, QProcess::ExitStatus) {
         QString json = QString::fromUtf8(ytdlProcess->readAllStandardOutput());
         QString title = QJsonDocument::fromJson(json.toUtf8())[QStringLiteral("title")].toString();
         if (title.isEmpty()) {
