@@ -21,7 +21,7 @@ public:
     enum { TextRole = Qt::UserRole, LanguageRole, TitleRole, IDRole, CodecRole };
     int rowCount(const QModelIndex &parent = QModelIndex()) const override;
     QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
-    virtual QHash<int, QByteArray> roleNames() const override;
+    QHash<int, QByteArray> roleNames() const override;
 
 public Q_SLOTS:
     void setTracks(QList<QVariant> tracks);
